const gulp       = require('gulp');
const rename     = require('gulp-rename');
const svgSymbols = require('gulp-svg-symbols');
const Elixir     = require('laravel-elixir');
const path       = require('path');


// Path to template file for SVG symbols
const svgTemplate = path.join(__dirname, 'templates/svg-symbols.scss');


const defaultOptions = {
    srcDir         : path.join(Elixir.config.assetsPath, 'svg'),
    outputDir      : path.join(Elixir.config.publicPath, 'svg'),
    outputFileName : 'symbols',
    title          : false,
    templates      : ['default-svg', svgTemplate],
    className      : '.svg-%f',
    id             : 'svg-%f',
};


const elixirSVGErrorNotification = function elixirSVGErrorNotification(error) {
    new Elixir.Notification().error(error, 'SVG symbols sprite sheet creation failed');
    this.emit('end');
};


const elixirSVGSuccessNotification = function elixirSVGSuccessNotification({ outputDir }) {
    return new Elixir.Notification().message(`SVG symbols sprite sheet created at ${outputDir}`);
};



Elixir.extend('svg', function elixirSVG(options) {

    const config = Object.assign({}, defaultOptions, options);

    new Elixir
        .Task('svg', function createSymbolSprite() {

            return gulp
                .src(config.srcDir + '/**/*.svg')
                .pipe(svgSymbols(config))
                .on('error', elixirSVGErrorNotification)
                .pipe(rename({ basename: config.outputFileName }))
                .pipe(gulp.dest(config.outputDir))
                .pipe(elixirSVGSuccessNotification(config));
        })
        .watch(path.join(config.srcDir, '**/*.svg'));
});